@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: cae_alsa.cpp,v 1.41 2008/07/18 20:06:10 fredg Exp $
+//      $Id: cae_alsa.cpp,v 1.41.2.3 2010/01/23 02:53:52 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -72,8 +72,8 @@ void AlsaCapture2Callback(struct alsa_format *alsa_format)
   while(!alsa_format->exiting) {
     int s=snd_pcm_readi(alsa_format->pcm,alsa_format->card_buffer,
 			rd_config->alsaPeriodSize()/(alsa_format->periods*2));
-    if((snd_pcm_state(alsa_format->pcm)!=SND_PCM_STATE_RUNNING)&&
-       (!alsa_format->exiting)) {
+    if(((snd_pcm_state(alsa_format->pcm)!=SND_PCM_STATE_RUNNING)&&
+	(!alsa_format->exiting))||(s<0)) {
       snd_pcm_drop (alsa_format->pcm);
       snd_pcm_prepare(alsa_format->pcm);
       LogLine(RDConfig::LogNotice,QString().
@@ -365,9 +365,9 @@ void AlsaPlay2Callback(struct alsa_format *alsa_format)
 	  // Process Output Meters
 	  //
 	  for(unsigned i=0;i<alsa_format->channels;i+=2) {
+	    unsigned port=i/2;
 	    for(unsigned j=0;j<2;j++) {
-	      out_meter[i][j]=0;
-	      out_meter[i+1][j]=0;
+	      out_meter[port][j]=0;
 	      for(unsigned k=0;k<alsa_format->buffer_size;k++) {
 		if(((short *)alsa_format->
 		    card_buffer)[alsa_format->channels*k+2*i+j]>
@@ -376,18 +376,9 @@ void AlsaPlay2Callback(struct alsa_format *alsa_format)
 		    ((short *)alsa_format->
 		     card_buffer)[alsa_format->channels*k+2*i+j];
 		}
-		if(((short *)alsa_format->
-		    card_buffer)[alsa_format->channels*k+2*i+1+j]>
-		   out_meter[i+1][j]) {
-		  out_meter[i+1][j]=
-		    ((short *)alsa_format->
-		     card_buffer)[alsa_format->channels*k+2*i+1+j];
-		}
 	      }
 	      alsa_output_meter[alsa_format->card][i][j]->
 		addValue(((double)out_meter[i][j])/32768.0);
-	      alsa_output_meter[alsa_format->card][i+1][j]->
-		addValue(((double)out_meter[i+1][j])/32768.0);
 	    }
 	  }
 	  break;
@@ -471,31 +462,22 @@ void AlsaPlay2Callback(struct alsa_format *alsa_format)
 	  // Process Output Meters
 	  //
 	  for(unsigned i=0;i<alsa_format->channels;i+=2) {
+	    unsigned port=i/2;
 	    for(unsigned j=0;j<2;j++) {
-	      out_meter[i][j]=0;
-	      out_meter[i+1][j]=0;
+	      out_meter[port][j]=0;
 	      for(unsigned k=0;
 		  k<(alsa_format->buffer_size*2/alsa_format->periods);
 		  k++) {
 		if(((short *)alsa_format->
-		    card_buffer)[alsa_format->channels*2*k+4*i+1+2*j]>
-		   out_meter[i][j]) {
-		  out_meter[i][j]=
+		    card_buffer)[alsa_format->channels*2*k+2*i+1+2*j]>
+		   out_meter[port][j]) {
+		  out_meter[port][j]=
 		    ((short *)alsa_format->
-		     card_buffer)[alsa_format->channels*2*k+4*i+1+2*j];
-		}
-		if(((short *)alsa_format->
-		    card_buffer)[alsa_format->channels*2*k+4*i+3+2*j]>
-		   out_meter[i+1][j]) {
-		  out_meter[i+1][j]=
-		    ((short *)alsa_format->
-		     card_buffer)[alsa_format->channels*2*k+4*i+3+2*j];
+		     card_buffer)[alsa_format->channels*2*k+2*i+1+2*j];
 		}
 	      }
-	      alsa_output_meter[alsa_format->card][i][j]->
-		addValue(((double)out_meter[i][j])/32768.0);
-	      alsa_output_meter[alsa_format->card][i+1][j]->
-		addValue(((double)out_meter[i+1][j])/32768.0);
+	      alsa_output_meter[alsa_format->card][port][j]->
+		addValue(((double)out_meter[port][j])/32768.0);
 	    }
 	  }
 	  break;
@@ -581,6 +563,7 @@ void MainObject::AlsaInitCallback()
 
 void MainObject::alsaStopTimerData(int cardstream)
 {
+  LogLine(RDConfig::LogErr,QString().sprintf("alsaStopTimerData(%d)",cardstream));
 #ifdef ALSA
   int card=cardstream/RD_MAX_STREAMS;
   int stream=cardstream-card*RD_MAX_STREAMS;
@@ -907,6 +890,7 @@ bool MainObject::alsaStopPlayback(int card,int stream)
   }
   alsa_playing[card][stream]=false;
   alsa_stop_timer[card][stream]->stop();
+  statePlayUpdate(card,stream,2);
   return true;
 #else
   return false;
