@@ -1482,6 +1482,18 @@ bitte erneut versuchen!</translation>
         <source>RadioTraffic.com Traffic Reconciliation</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>VisualTraffic Reconciliation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>CounterPoint Traffic Reconciliation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Music1 Reconciliation</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDSoundPanel</name>
