@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rddropbox.cpp,v 1.4 2007/10/04 20:53:28 dmills Exp $
+//      $Id: rddropbox.cpp,v 1.5.2.1 2008/11/29 15:48:09 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,6 +23,7 @@
 #include <rddb.h>
 #include <rdconf.h>
 #include <rddropbox.h>
+#include <rdescape_string.h>
 
 
 //
@@ -178,6 +179,19 @@ void RDDropbox::setDeleteCuts(bool state) const
 }
 
 
+bool RDDropbox::deleteSource() const
+{
+  return RDBool(RDGetSqlValue("DROPBOXES","ID",box_id,"DELETE_SOURCE").
+		toString());
+}
+
+
+void RDDropbox::setDeleteSource(bool state) const
+{
+  SetRow("DELETE_SOURCE",state);
+}
+
+
 QString RDDropbox::metadataPattern() const
 {
   return RDGetSqlValue("DROPBOXES","ID",box_id,"METADATA_PATTERN").toString();
@@ -190,6 +204,30 @@ void RDDropbox::setMetadataPattern(const QString &str) const
 }
 
 
+int RDDropbox::startdateOffset() const
+{
+  return RDGetSqlValue("DROPBOXES","ID",box_id,"STARTDATE_OFFSET").toInt();
+}
+
+
+void RDDropbox::setStartdateOffset(int offset) const
+{
+  SetRow("STARTDATE_OFFSET",offset);
+}
+
+
+int RDDropbox::enddateOffset() const
+{
+  return RDGetSqlValue("DROPBOXES","ID",box_id,"ENDDATE_OFFSET").toInt();
+}
+
+
+void RDDropbox::setEnddateOffset(int offset) const
+{
+  SetRow("ENDDATE_OFFSET",offset);
+}
+
+
 bool RDDropbox::fixBrokenFormats() const
 {
   return RDBool(RDGetSqlValue("DROPBOXES","ID",box_id,"FIX_BROKEN_FORMATS").
@@ -215,7 +253,7 @@ void RDDropbox::setLogPath(const QString &path) const
 }
 
 
-void RDDropbox::SetRow(QString param,int value) const
+void RDDropbox::SetRow(const QString &param,int value) const
 {
   RDSqlQuery *q;
   QString sql;
@@ -227,7 +265,7 @@ void RDDropbox::SetRow(QString param,int value) const
 }
 
 
-void RDDropbox::SetRow(QString param,unsigned value) const
+void RDDropbox::SetRow(const QString &param,unsigned value) const
 {
   RDSqlQuery *q;
   QString sql;
@@ -239,19 +277,21 @@ void RDDropbox::SetRow(QString param,unsigned value) const
 }
 
 
-void RDDropbox::SetRow(QString param,QString value) const
+void RDDropbox::SetRow(const QString &param,const QString &value) const
 {
   RDSqlQuery *q;
   QString sql;
 
   sql=QString().sprintf("update DROPBOXES set %s=\"%s\" where ID=%d",
-			(const char *)param,(const char *)value,box_id);
+			(const char *)param,
+			(const char *)RDEscapeString(value),
+			box_id);
   q=new RDSqlQuery(sql);
   delete q;
 }
 
 
-void RDDropbox::SetRow(QString param,bool value) const
+void RDDropbox::SetRow(const QString &param,bool value) const
 {
   RDSqlQuery *q;
   QString sql;
