@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdevent_line.cpp,v 1.54.2.2 2009/02/03 15:35:52 cvs Exp $
+//      $Id: rdevent_line.cpp,v 1.54.2.4 2010/02/18 01:14:17 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -507,13 +507,13 @@ bool RDEventLine::generateLog(QString logname,const QString &svcname,
   for(int i=0;i<event_preimport_log->size();i++) {
     if((logline=event_preimport_log->logLine(i))!=NULL) {
       sql=QString().sprintf("insert into `%s_LOG` set ID=%d,COUNT=%d,TYPE=%d,\
-                             SOURCE=%d,START_TIME=\"%s\",GRACE_TIME=%d,\
+                             SOURCE=%d,START_TIME=%d,GRACE_TIME=%d,\
                              CART_NUMBER=%u,TIME_TYPE=%d,POST_POINT=\"%s\",\
                              TRANS_TYPE=%d,COMMENT=\"%s\"",
 			    (const char *)logname,count,count,
 			    logline->type(),
 			    RDLogLine::Template,
-			    (const char *)time.toString("hh:mm:ss"),
+			    QTime().msecsTo(time),
 			    grace_time,logline->cartNumber(),
 			    time_type,
 			    (const char *)RDYesNo(post_point),
@@ -559,20 +559,21 @@ bool RDEventLine::generateLog(QString logname,const QString &svcname,
     QTime end_start_time=event_start_time.addMSecs(event_length);
 
     sql=QString().sprintf("insert into `%s_LOG` set ID=%d,COUNT=%d,TYPE=%d,\
-                           SOURCE=%d,START_TIME=\"%s\",GRACE_TIME=%d,\
+                           SOURCE=%d,START_TIME=%d,GRACE_TIME=%d,\
                            TIME_TYPE=%d,POST_POINT=\"%s\",TRANS_TYPE=%d,\
-                           LINK_EVENT_NAME=\"%s\",LINK_START_TIME=\"%s\",\
+                           LINK_EVENT_NAME=\"%s\",LINK_START_TIME=%d,\
                            LINK_LENGTH=%d,LINK_ID=%d,LINK_START_SLOP=%d,\
                            LINK_END_SLOP=%d",
 			  (const char *)logname,count,count,
 			  link_type,RDLogLine::Template,
-			  (const char *)time.toString("hh:mm:ss"),
+			  QTime().msecsTo(time),
 			  grace_time,
 			  time_type,
 			  (const char *)RDYesNo(post_point),
 			  trans_type,
 			  (const char *)RDEscapeString(event_name),
-			  (const char *)event_start_time.toString("hh:mm:ss"),
+//			  (const char *)event_start_time.toString("hh:mm:ss"),
+			  QTime().msecsTo(event_start_time),
 			  event_start_time.msecsTo(end_start_time),
 			  link_id,
 			  event_start_slop,
@@ -790,17 +791,17 @@ bool RDEventLine::generateLog(QString logname,const QString &svcname,
       
       int schedpos = rand()%schedCL->getNumberOfItems();
       sql=QString().sprintf("insert into %s_LOG set ID=%d,COUNT=%d,TYPE=%d,\
-				  SOURCE=%d,START_TIME=\"%s\",GRACE_TIME=-1, \
+				  SOURCE=%d,START_TIME=%d,GRACE_TIME=-1, \
 				  CART_NUMBER=%u,TIME_TYPE=%d,POST_POINT=\"%s\", \
-				  TRANS_TYPE=%d,EXT_START_TIME=\"%s\"",
+				  TRANS_TYPE=%d,EXT_START_TIME=%d",
 			    (const char *)logname,count,count,
 			    RDLogLine::Cart,source,
-			    (const char *)time.toString("hh:mm:ss"),
+			    QTime().msecsTo(time),
 			    schedCL->getItemCartnumber(schedpos),
 			    time_type,
 			    (const char *)RDYesNo(post_point),
 			    trans_type,
-			    (const char *)time.toString("hh:mm:ss"));
+			    QTime().msecsTo(time));
       q=new RDSqlQuery(sql);
       delete q;
       
@@ -824,13 +825,13 @@ bool RDEventLine::generateLog(QString logname,const QString &svcname,
   for(int i=0;i<event_postimport_log->size();i++) {
     if((logline=event_postimport_log->logLine(i))!=NULL) {
       sql=QString().sprintf("insert into `%s_LOG` set ID=%d,COUNT=%d,TYPE=%d,\
-                             SOURCE=%d,START_TIME=\"%s\",GRACE_TIME=%d,\
+                             SOURCE=%d,START_TIME=%d,GRACE_TIME=%d,\
                              CART_NUMBER=%u,TIME_TYPE=%d,POST_POINT=\"%s\",\
                              TRANS_TYPE=%d,COMMENT=\"%s\"",
 			    (const char *)logname,count,count,
 			    logline->type(),
 			    RDLogLine::Template,
-			    (const char *)time.toString("hh:mm:ss"),
+			    QTime().msecsTo(time),
 			    grace_time,logline->cartNumber(),
 			    time_type,
 			    (const char *)RDYesNo(post_point),
