@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdlog_line.cpp,v 1.107.2.3 2009/04/13 16:07:06 cvs Exp $
+//      $Id: rdlog_line.cpp,v 1.107.2.4 2009/11/17 17:45:53 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -121,6 +121,8 @@ void RDLogLine::clear()
   log_play_order=RDCart::Sequence;
   log_enforce_length=false;
   log_preserve_pitch=false;
+  log_start_datetime=QDateTime();
+  log_end_datetime=QDateTime();
   log_deck=-1;
   log_port_name="";
   log_play_time=QTime();
@@ -237,6 +239,18 @@ RDCart::Validity RDLogLine::validity() const
 }
 
 
+RDCart::Validity RDLogLine::validity(const QDateTime &datetime) const
+{
+  if(datetime.isNull()||log_end_datetime.isNull()) {
+    return log_validity;
+  }
+  if(datetime>log_end_datetime) {
+    return RDCart::NeverValid;
+  }
+  return log_validity;
+}
+
+
 void RDLogLine::setValidity(RDCart::Validity valid)
 {
   log_validity=valid;
@@ -916,6 +930,30 @@ void RDLogLine::setPreservePitch(bool state)
 }
 
 
+QDateTime RDLogLine::startDatetime() const
+{
+  return log_start_datetime;
+}
+
+
+void RDLogLine::setStartDatetime(const QDateTime &datetime)
+{
+  log_start_datetime=datetime;
+}
+
+
+QDateTime RDLogLine::endDatetime() const
+{
+  return log_end_datetime;
+}
+
+
+void RDLogLine::setEndDatetime(const QDateTime &datetime)
+{
+  log_end_datetime=datetime;
+}
+
+
 RDListViewItem *RDLogLine::listViewItem() const
 {
   return log_listview;
@@ -1629,8 +1667,9 @@ void RDLogLine::loadCart(int cartnum,RDLogLine::TransType next_type,int mach,
   log_cut_quantity=q->value(12).toUInt();
   log_last_cut_played=q->value(13).toUInt();
   log_play_order=(RDCart::PlayOrder)q->value(14).toInt();
-  log_enforce_length=RDBool(q->value(15).toString());
-  log_preserve_pitch=RDBool(q->value(!6).toString());
+  log_start_datetime=q->value(15).toDateTime();
+  log_end_datetime=q->value(16).toDateTime();
+  log_preserve_pitch=RDBool(q->value(18).toString());
   log_enforce_length=RDBool(q->value(17).toString());
   log_now_next_enabled=RDBool(q->value(19).toString());
   log_asyncronous=RDBool(q->value(20).toString());
