@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdpodcast.cpp,v 1.6.2.1 2009/01/30 19:51:13 cvs Exp $
+//      $Id: rdpodcast.cpp,v 1.6.2.1.2.1 2010/05/11 14:43:12 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -319,23 +319,25 @@ QString RDPodcast::audioUploadCommand(const QString &srcfile) const
   if(url.protocol()=="ftp") {
     QString dir=RDGetPathPart(url.path());
     if(dir.right(dir.length()-1).isEmpty()) {
-      cmd=QString().sprintf("lftp -e \"put %s -o %s;bye\"",
-			  (const char *)srcfile,
-			  (const char *)RDGetBasePart(url.path()));
+      cmd=QString().
+	sprintf("lftp -e \"set net:max-retries 1;put %s -o %s;bye\"",
+		(const char *)srcfile,
+		(const char *)RDGetBasePart(url.path()));
     }
     else {
-      cmd=QString().sprintf("lftp -e \"put -O %s %s -o %s;bye\"",
-			  (const char *)dir.right(dir.length()-1),
-			  (const char *)srcfile,
-			  (const char *)RDGetBasePart(url.path()));
+      cmd=QString().
+	sprintf("lftp -e \"set net:max-retries 1;put -O %s %s -o %s;bye\"",
+		(const char *)dir.right(dir.length()-1),
+		(const char *)srcfile,
+		(const char *)RDGetBasePart(url.path()));
     }
     if(!purge_username.isEmpty()) {
-      cmd+=QString().sprintf(" -u \"%s",(const char *)purge_username);
+      cmd+=QString().sprintf(" -u \"%s:",(const char *)purge_username);
       if(purge_password.isEmpty()) {
 	cmd+="\"";
       }
       else {
-	cmd+=QString().sprintf(",%s\"",(const char *)purge_password);
+	cmd+=QString().sprintf("%s\"",(const char *)purge_password);
       }
     }
     cmd+=QString().sprintf(" %s",(const char *)url.host());
@@ -400,15 +402,15 @@ QString RDPodcast::audioPurgeCommand() const
 			  (const char *)audio_filename);
   }
   if(url.protocol()=="ftp") {
-    cmd=QString().sprintf("lftp -e \"rm %s;bye\"",
+    cmd=QString().sprintf("lftp -e \"set net:max-retries 1;rm %s;bye\"",
 			  (const char *)audio_filename);
     if(!purge_username.isEmpty()) {
-      cmd+=QString().sprintf(" -u \"%s",(const char *)purge_username);
+      cmd+=QString().sprintf(" -u \"%s:",(const char *)purge_username);
       if(purge_password.isEmpty()) {
 	cmd+="\"";
       }
       else {
-	cmd+=QString().sprintf(",%s\"",(const char *)purge_password);
+	cmd+=QString().sprintf("%s\"",(const char *)purge_password);
       }
     }
     cmd+=QString().sprintf(" ftp://%s%s",(const char *)url.host(),
