@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: add_matrix.cpp,v 1.25.2.1 2009/08/07 01:14:08 cvs Exp $
+//      $Id: add_matrix.cpp,v 1.25.2.1.2.2 2010/05/08 23:01:57 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -102,6 +102,8 @@ AddMatrix::AddMatrix(QString station,QWidget *parent,const char *name)
   add_type_box->insertItem(tr("Axia LiveWire"));
   add_type_box->insertItem(tr("Quartz Type 1"));
   add_type_box->insertItem(tr("BroadcastTools SS4.4"));
+  add_type_box->insertItem(tr("BroadcastTools SRC-8 III"));
+  add_type_box->insertItem(tr("BroadcastTools SRC-16"));
   label=new QLabel(add_type_box,tr("&Switcher Type:"),this,
 		   "matrix_label");
   label->setGeometry(10,36,150,19);
@@ -275,6 +277,20 @@ void AddMatrix::okData()
 	gpos=8;
 	break;
 
+      case RDMatrix::BtSrc8III:
+	inputs=0;
+	outputs=0;
+	gpis=8;
+	gpos=8;
+	break;
+
+      case RDMatrix::BtSrc16:
+	inputs=0;
+	outputs=0;
+	gpis=16;
+	gpos=16;
+	break;
+
       default:
 	inputs=0;
 	outputs=0;
