@@ -1,10 +1,11 @@
+
 // edit_feed.h
 //
 // Edit a Rivendell Feed
 //
 //   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_feed.h,v 1.6 2008/09/26 17:52:23 fredg Exp $
+//      $Id: edit_feed.h,v 1.6.2.4 2009/05/26 18:33:30 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -30,6 +31,8 @@
 #include <qsqldatabase.h>
 #include <qcheckbox.h>
 #include <qlabel.h>
+#include <qcombobox.h>
+#include <qpushbutton.h>
 
 #include <rdfeed.h>
 #include <rdsettings.h>
@@ -50,6 +53,7 @@ class EditFeed : public QDialog
   void setFormatData();
   void normalizeCheckData(bool state);
   void editData();
+  void redirectToggledData(bool state);
   void okData();
   void cancelData();
   
@@ -57,6 +61,7 @@ class EditFeed : public QDialog
   void paintEvent(QPaintEvent *e);
 
  private:
+  void RedirectChanged(bool state);
   RDFeed *feed_feed;
   QLineEdit *feed_keyname_edit;
   QLineEdit *feed_channel_title_edit;
@@ -67,6 +72,7 @@ class EditFeed : public QDialog
   QLineEdit *feed_channel_webmaster_edit;
   QLineEdit *feed_channel_language_edit;
   QLineEdit *feed_base_url_edit;
+  QLineEdit *feed_base_preamble_edit;
   QLineEdit *feed_purge_url_edit;
   QLabel *feed_purge_username_label;
   QLineEdit *feed_purge_username_edit;
@@ -83,8 +89,39 @@ class EditFeed : public QDialog
   QCheckBox *feed_normalize_box;
   QLabel *feed_normalize_label;
   QSpinBox *feed_normalize_spin;
-  QLabel *feed_normalize_unit;
   QLineEdit *feed_extension_edit;
+  QComboBox *feed_castorder_box;
+  QComboBox *feed_media_link_mode_box;
+  QCheckBox *feed_redirect_check;
+  QLabel *feed_redirect_label;
+  QLineEdit *feed_redirect_edit;
+  QPushButton *feed_format_button;
+  QPushButton *feed_metadata_button;
+
+  QLabel *feed_channel_title_label;
+  QLabel *feed_channel_category_label;
+  QLabel *feed_channel_link_label;
+  QLabel *feed_channel_copyright_label;
+  QLabel *feed_channel_webmaster_label;
+  QLabel *feed_channel_language_label;
+  QLabel *feed_channel_description_label;
+  QLabel *feed_base_url_label;
+  QLabel *feed_base_preamble_label;
+  QLabel *feed_purge_url_label;
+  QLabel *feed_max_shelf_life_label;
+  QLabel *feed_max_shelf_life_unit_label;
+  QLabel *feed_autopost_label;
+  QLabel *feed_keep_metadata_label;
+  QLabel *feed_format_label;
+  QLabel *feed_normalize_check_label;
+  QLabel *feed_normalize_unit_label;
+  QLabel *feed_castorder_label;
+  QLabel *feed_media_link_mode_label;
+  QLabel *feed_extension_label;
+  QLabel *feed_header_xml_label;
+  QLabel *feed_channel_xml_label;
+  QLabel *feed_item_xml_label;
+  QLabel *feed_channel_section_label;
 };
 
 
