@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: list_matrices.cpp,v 1.25.2.1 2009/08/07 01:14:08 cvs Exp $
+//      $Id: list_matrices.cpp,v 1.25.2.1.2.2 2010/05/08 23:01:57 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -402,6 +402,12 @@ QString ListMatrices::TypeString(RDMatrix::Type type)
       case RDMatrix::BtSs44:
 	return QString(tr("BroadcastTools SS4.4"));
 
+      case RDMatrix::BtSrc8III:
+	return QString(tr("BroadcastTools SRC-8 III"));
+
+      case RDMatrix::BtSrc16:
+	return QString(tr("BroadcastTools SRC-16"));
+
       default:
 	return QString(tr("Unknown"));
   }
