@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: loglinebox.cpp,v 1.80 2007/09/14 14:06:48 fredg Exp $
+//      $Id: loglinebox.cpp,v 1.83.2.2 2010/02/08 23:50:14 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -42,9 +42,9 @@
 LogLineBox::LogLineBox(QWidget *parent,const char *name)
   : QWidget(parent,name)
 {
+  line_type=RDLogLine::UnknownType;
   line_mode=LogLineBox::Full;
   line_time_mode=RDAirPlayConf::TwentyFourHour;
-  line_time_format="hh:mm:ss";
   log_id=-1;
   log_line=-1;
 
@@ -141,14 +141,14 @@ LogLineBox::LogLineBox(QWidget *parent,const char *name)
   // Group
   //
   line_group_label=new QLabel(this,"line_group_label");
-  line_group_label->setGeometry(107,3,90,16);
+  line_group_label->setGeometry(107,3,75,16);
   line_group_label->setFont(line_bold_font);
 
   //
   // Time
   //
   line_time_label=new QLabel(this,"line_time_label");
-  line_time_label->setGeometry(200,3,70,16);
+  line_time_label->setGeometry(185,3,85,16);
   line_time_label->setFont(line_font);
   line_time_label->setAlignment(AlignRight);
   line_time_label->setPalette(line_time_palette);
@@ -195,10 +195,18 @@ LogLineBox::LogLineBox(QWidget *parent,const char *name)
   // Outcue
   //
   line_outcue_label=new QLabel(this,"line_outcue_label");
-  line_outcue_label->setGeometry(5,48,sizeHint().width()-10,16);
+  line_outcue_label->setGeometry(5,48, (sizeHint().width()/2 -10),16);
   line_outcue_label->setFont(outcue_font);
   line_outcue_label->hide();
 
+  //
+  // Cut Description
+  //
+  line_description_label=new QLabel(this,"line_description_label");
+  line_description_label->setGeometry((sizeHint().width()/2),48,(sizeHint().width()/2 -10),14);
+  line_description_label->setFont(line_font);
+  line_description_label->hide();
+
   //
   // Marker Comment
   //
@@ -300,11 +308,13 @@ void LogLineBox::setMode(LogLineBox::Mode mode)
 		line_up_label->show();
 		line_down_label->show();
 		line_position_bar->show();
+                line_description_label->show();
 	      }
 	      else {
 		line_up_label->hide();
 		line_down_label->hide();
 		line_position_bar->hide();
+                line_description_label->hide();
 	      }
 	      break;
 
@@ -315,6 +325,7 @@ void LogLineBox::setMode(LogLineBox::Mode mode)
 	      line_up_label->hide();
 	      line_down_label->hide();
 	      line_position_bar->hide();
+              line_description_label->hide();
 	      break;
 
 	    default:
@@ -327,6 +338,7 @@ void LogLineBox::setMode(LogLineBox::Mode mode)
 	line_up_label->hide();
 	line_down_label->hide();
 	line_position_bar->hide();
+        line_description_label->hide();
 	line_comment_label->setGeometry(5,18,sizeHint().width()-10,31);
 	break;
   }
@@ -359,6 +371,7 @@ void LogLineBox::setEvent(int line,RDLogLine::TransType next_type,
   line_next_type=next_type;
 
   RDCart *cart;
+  RDCut *cut;
 
   log_id=logline->id();
   log_line=line;
@@ -384,16 +397,6 @@ void LogLineBox::setEvent(int line,RDLogLine::TransType next_type,
 	}
 	break;
 
-      case RDLogLine::Overlap:
-	line_trans_label->setText(tr("OVRLAP"));
-	if(logline->hasCustomTransition()) {
-	  line_trans_label->setPalette(line_transition_palette);
-	}
-	else {
-	  line_trans_label->setPalette(palette());
-	}
-	break;
-
       default:
 	break;
   }
@@ -401,9 +404,12 @@ void LogLineBox::setEvent(int line,RDLogLine::TransType next_type,
       case RDLogLine::Cart:
 	line_comment_label->hide();
 	cart=new RDCart(logline->cartNumber());
+        cut=new RDCut(QString().sprintf("%06u_%03u",logline->cartNumber(),
+                                        logline->cutNumber()));
 	if(!cart->exists()) {
 	  line_cart_label->
 	    setText(QString().sprintf("%06u",logline->cartNumber()));
+	  line_description_label->clear();
 	  line_artist_label->clear();
 	  line_cut_label->clear();
 	  line_group_label->clear();
@@ -417,12 +423,14 @@ void LogLineBox::setEvent(int line,RDLogLine::TransType next_type,
 	  line_title_label->setText(tr("[CART NOT FOUND]"));
 	  SetColor(QColor(LOGLINEBOX_MISSING_COLOR));
 	  delete cart;
+          delete cut;
 	}
 	else {
 	  if(((cart->forcedLength()==0)&&(cart->type()==RDCart::Audio))||
 	     (line_logline->state()==RDLogLine::NoCut)) {
 	    line_cart_label->
 	      setText(QString().sprintf("%06u",logline->cartNumber()));
+	    line_description_label->setText(cut->description());
 	    line_artist_label->setText(tr("[NO AUDIO AVAILABLE]"));
 	    line_cut_label->clear();
 	    line_group_label->clear();
@@ -436,6 +444,7 @@ void LogLineBox::setEvent(int line,RDLogLine::TransType next_type,
 	    line_title_label->setText(logline->title());
 	    SetColor(QColor(LOGLINEBOX_MISSING_COLOR));
 	    delete cart;
+            delete cut;
 	  }
 	  else {
 	    line_cart_label->
@@ -485,6 +494,7 @@ void LogLineBox::setEvent(int line,RDLogLine::TransType next_type,
 				 (const char *)line_logline->originDateTime().
 				 toString("M/d hh:mm")));
 	    }
+	    line_description_label->setText(cut->description());
 	    line_artist_label->setText(cart->artist());
 	    line_up_label->
 	      setText(RDGetTimeLength(line_logline->playPosition(),true,true));
@@ -504,6 +514,7 @@ void LogLineBox::setEvent(int line,RDLogLine::TransType next_type,
 	      line_outcue_label->setText(tr("[NO VALID CUT AVAILABLE]"));
 	    }
 	    delete cart;
+	    delete cut;
 	    setMode(line_mode);
 	    line_title_label->show();
 	    line_artist_label->show();
@@ -515,6 +526,7 @@ void LogLineBox::setEvent(int line,RDLogLine::TransType next_type,
 	line_icon_label->setPixmap(*line_notemarker_map);
 	SetColor(QColor(LOGLINEBOX_MARKER_COLOR));
 	line_title_label->hide();
+	line_description_label->hide();
 	line_artist_label->hide();
 	line_cart_label->setText(tr("MARKER"));
 	line_group_label->setText(logline->markerLabel());
@@ -529,6 +541,7 @@ void LogLineBox::setEvent(int line,RDLogLine::TransType next_type,
 	line_icon_label->setPixmap(*line_mic16_map);
 	SetColor(QColor(LOGLINEBOX_MARKER_COLOR));
 	line_title_label->hide();
+	line_description_label->hide();
 	line_artist_label->hide();
 	line_cart_label->setText(tr("TRACK"));
 	line_group_label->setText("");
@@ -543,6 +556,7 @@ void LogLineBox::setEvent(int line,RDLogLine::TransType next_type,
 	line_icon_label->setPixmap(*line_music_map);
 	SetColor(QColor(LOGLINEBOX_MARKER_COLOR));
 	line_title_label->hide();
+	line_description_label->hide();
 	line_artist_label->hide();
 	line_cart_label->setText(tr("LINK"));
 	line_group_label->setText("");
@@ -557,6 +571,7 @@ void LogLineBox::setEvent(int line,RDLogLine::TransType next_type,
 	line_icon_label->setPixmap(*line_traffic_map);
 	SetColor(QColor(LOGLINEBOX_MARKER_COLOR));
 	line_title_label->hide();
+	line_description_label->hide();
 	line_artist_label->hide();
 	line_cart_label->setText(tr("LINK"));
 	line_group_label->setText("");
@@ -571,6 +586,7 @@ void LogLineBox::setEvent(int line,RDLogLine::TransType next_type,
 	line_icon_label->setPixmap(*line_chain_map);
 	SetColor(QColor(LOGLINEBOX_CHAIN_COLOR));
 	line_title_label->setText(logline->markerLabel());
+	line_description_label->setText("");
 	line_artist_label->setText(logline->markerComment());
 	line_cart_label->setText(tr("CHAIN"));
 	line_group_label->setText("");
@@ -586,6 +602,8 @@ void LogLineBox::setEvent(int line,RDLogLine::TransType next_type,
 	line_icon_label->setPixmap(*line_macro_map);
 	line_comment_label->hide();
 	cart=new RDCart(logline->cartNumber());
+        cut=new RDCut(QString().sprintf("%06u_%03u",logline->cartNumber(),
+                                        logline->cutNumber()));
 	if(!cart->exists()) {
 	  SetColor(QColor(LOGLINEBOX_MISSING_COLOR));
 	}
@@ -599,11 +617,14 @@ void LogLineBox::setEvent(int line,RDLogLine::TransType next_type,
 	p.setColor(QColorGroup::Foreground,line_logline->groupColor());
 	line_group_label->setPalette(p);
 	line_length_label->
-	  setText(RDGetTimeLength(line_logline->effectiveLength(),false,false));
+	  setText(RDGetTimeLength(line_logline->effectiveLength(),
+				  false,false));
 	line_title_label->setText(cart->title());
+	line_description_label->setText("");
 	line_artist_label->setText(cart->artist());
 	line_outcue_label->setText("");
 	delete cart;
+	delete cut;
 	setMode(line_mode);
 	line_title_label->show();
 	line_artist_label->show();
@@ -633,6 +654,7 @@ void LogLineBox::clear()
   line_group_label->setText("");
   line_trans_label->setText("");
   line_title_label->setText("");
+  line_description_label->setText("");
   line_artist_label->setText("");
   line_outcue_label->setText("");
   line_outcue_label->hide();
@@ -654,7 +676,6 @@ void LogLineBox::clear()
   line_up_label->hide();
   line_position_bar->hide();
   line_down_label->hide();
-  line_time_format="hh:mm:ss";
   line_icon_label->clear();
   setBarMode(LogLineBox::Stopping);
 }
@@ -699,17 +720,8 @@ void LogLineBox::setTimeMode(RDAirPlayConf::TimeMode mode)
   if(mode==line_time_mode) {
     return;
   }
-  switch(mode) {
-      case RDAirPlayConf::TwentyFourHour:
-	line_time_format="hh:mm:ss";
-	break;
-	
-      case RDAirPlayConf::TwelveHour:
-	line_time_format="h:mm:ss ap";
-	break;
-  }
-  PrintTime();
   line_time_mode=mode;
+  PrintTime();
 }
 
 
@@ -724,11 +736,8 @@ void LogLineBox::mouseDoubleClickEvent(QMouseEvent *e)
   if(line_logline==NULL) {
     return;
   }
- // if((line_logline->status()==RDLogLine::Scheduled)||
- //    (line_logline->status()==RDLogLine::Paused)) {
-    emit doubleClicked(log_line);
-    QWidget::mouseDoubleClickEvent(e);
- // }
+  emit doubleClicked(log_line);
+  QWidget::mouseDoubleClickEvent(e);
 }
 
 
@@ -749,6 +758,7 @@ void LogLineBox::SetColor(QColor color)
   line_group_label->setBackgroundColor(color);
   line_trans_label->setBackgroundColor(color);
   line_title_label->setBackgroundColor(color);
+  line_description_label->setBackgroundColor(color);
   line_artist_label->setBackgroundColor(color);
   line_outcue_label->setBackgroundColor(color);
   line_time_label->setBackgroundColor(color);
@@ -787,11 +797,9 @@ void LogLineBox::PrintTime()
       case RDLogLine::Hard:
 	line_time_label->setFont(line_bold_font);
 	str=QString(tr("T"));
-	line_time_label->
-	  setText(QString().sprintf("%s%s",(const char *)str,
-				    (const char *)line_logline->
-				    startTime(RDLogLine::Logged).
-				    toString(line_time_format)));
+	line_time_label->setText(QString().sprintf("%s%s",(const char *)str,
+		     (const char *)TimeString(line_logline->
+					      startTime(RDLogLine::Logged))));
 	line_time_label->setPalette(line_hard_palette);
 	break;
 
@@ -799,9 +807,9 @@ void LogLineBox::PrintTime()
 	line_time_label->setFont(line_font);
 	if(!line_logline->startTime(RDLogLine::Logged).isNull()) {
 	  line_time_label->
-	    setText(QString().sprintf("%s",(const char *)line_logline->
-				      startTime(RDLogLine::Logged).
-				      toString(line_time_format)));
+	    setText(QString().sprintf("%s",
+				      (const char *)TimeString(line_logline->
+					   startTime(RDLogLine::Logged))));
 	}
 	else {
 	  line_time_label->setText("");
@@ -810,3 +818,21 @@ void LogLineBox::PrintTime()
 	break;
   }
 }
+
+
+QString LogLineBox::TimeString(const QTime &time)
+{
+  QString ret;
+  switch(line_time_mode) {
+  case RDAirPlayConf::TwelveHour:
+    ret=time.toString("h:mm:ss.zzz");
+    ret=ret.left(ret.length()-2);
+    ret+=(" "+time.toString("ap"));
+    break;
+
+  case RDAirPlayConf::TwentyFourHour:
+    ret=time.toString("hh:mm:ss.zzz").left(10);
+    break;
+  }
+  return ret;
+}
