@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2008 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdairplay.cpp,v 1.171.2.8 2009/06/29 15:55:15 cvs Exp $
+//      $Id: rdairplay.cpp,v 1.171.2.9.2.1 2010/06/03 22:54:42 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -796,6 +796,11 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   }
   delete q;
 
+  //
+  // Set Signal Handlers
+  //
+  signal(SIGCHLD,SigHandler);
+
   //
   // Start the RIPC Connection
   //
@@ -1549,14 +1554,14 @@ void MainWidget::keyPressEvent(QKeyEvent *e)
       case Qt::Key_X:
 	if(((e->state()&AltButton)!=0)&&
 	   ((e->state()&ShiftButton)==0)&&((e->state()&ControlButton)==0)) {
-	  QCloseEvent *e=new QCloseEvent();
-	  closeEvent(e);
-	  delete e;
+	  QCloseEvent *ce=new QCloseEvent();
+	  closeEvent(ce);
+	  delete ce;
 	}
 	break;
 
       default:
-	QWidget::keyPressEvent(e);
+	e->ignore();
 	break;
   }
 }
