@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: add_recording.cpp,v 1.24 2007/12/31 18:49:09 fredg Exp $
+//      $Id: add_recording.cpp,v 1.24.2.1 2010/02/09 21:43:53 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -219,8 +219,8 @@ void AddRecording::playoutData()
 
 void AddRecording::downloadData()
 {
-  EditDownload *recording=new EditDownload(add_id,NULL,add_filter,
-					   this,"recording");
+  EditDownload *recording=
+    new EditDownload(add_id,NULL,add_filter,this,"recording");
   if(recording->exec()<0) {
     delete recording;
     done(-1);
