@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: disk_ripper.cpp,v 1.23.2.2 2009/04/03 11:44:10 cvs Exp $
+//      $Id: disk_ripper.cpp,v 1.23.2.4 2009/09/04 01:29:50 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -605,17 +605,10 @@ void DiskRipper::autotrimCheckData(bool state)
 void DiskRipper::barTimerData()
 {
   if(ripper_running) {
-    if(rip_multipass) {
-      rip_track_bar->
-	setProgress((int)(50.0*((double)bar_temp_file->
-				size()/(double)rip_temp_length+
-				(double)bar_file->size()/
-				(double)rip_finished_length)));
-    }
-    else {
-      rip_track_bar->setProgress((int)(100.0*(double)bar_file->size()/
-				 (double)rip_finished_length));
-    }
+    rip_track_bar->setProgress((int)(50.0*((double)bar_temp_file->
+					   size()/(double)rip_temp_length+
+					   (double)bar_file->size()/
+					   (double)rip_finished_length)));
     rip_disk_bar->setProgress(rip_base_length+bar_temp_file->size()+
 			      bar_file->size());
     rip_bar_timer->start(RIPPER_BAR_INTERVAL,true);
@@ -838,37 +831,41 @@ void DiskRipper::RipTrack(int track,QString cutname,QString title)
 	break;
   }
   if(rip_normalize_box->isChecked()) {
-    cmd=QString().sprintf("rd_rip_cd %d %s %d %6.4lf %d %d %d %d %s %s/%s %s/%s",
-			  rip_track_number,
-			  (const char *)rdlibrary_conf->ripperDevice(),
-			  rdlibrary_conf->paranoiaLevel(),
-			  pow(10.0,(double)(rip_normalize_spin->value())/20.0),
-			  rdlibrary_conf->defaultFormat(),
-			  rip_channels_box->currentItem()+1,
-			  rdlibrary_conf->defaultSampleRate(),
-			  (rip_channels_box->currentItem()+1)*rdlibrary_conf->defaultBitrate()/1000, 
-			  (const char *)rip_wavefile,
-			  RIPPER_TEMP_DIR,
-			  RIPPER_TEMP_PEAK,
-			  RIPPER_TEMP_DIR,
-			  RIPPER_TEMP_WAV);
-    rip_multipass=true;
+    cmd=QString().
+      sprintf("rd_rip_cd %d %s %d %6.4lf %d %d %d %d %s %s/%s %s/%s %d",
+	      rip_track_number,
+	      (const char *)rdlibrary_conf->ripperDevice(),
+	      rdlibrary_conf->paranoiaLevel(),
+	      pow(10.0,(double)(rip_normalize_spin->value())/20.0),
+	      rdlibrary_conf->defaultFormat(),
+	      rip_channels_box->currentItem()+1,
+	      rdlibrary_conf->defaultSampleRate(),
+	      (rip_channels_box->currentItem()+1)*
+	      rdlibrary_conf->defaultBitrate()/1000, 
+	      (const char *)rip_wavefile,
+	      RIPPER_TEMP_DIR,
+	      RIPPER_TEMP_PEAK,
+	      RIPPER_TEMP_DIR,
+	      RIPPER_TEMP_WAV,
+	      rdlibrary_conf->srcConverter());
   }
   else {
-    cmd=QString().sprintf("rd_rip_cd %d %s %d 0 %d %d %d %d %s %s/%s %s/%s",
-			  rip_track_number,
-			  (const char *)rdlibrary_conf->ripperDevice(),
-			  rdlibrary_conf->paranoiaLevel(),
-			  rdlibrary_conf->defaultFormat(),
-			  rip_channels_box->currentItem()+1,
-			  rdlibrary_conf->defaultSampleRate(),
-			  (rip_channels_box->currentItem()+1)*rdlibrary_conf->defaultBitrate()/1000,
-			  (const char *)rip_wavefile,
-			  RIPPER_TEMP_DIR,
-			  RIPPER_TEMP_PEAK,
-			  RIPPER_TEMP_DIR,
-			  RIPPER_TEMP_WAV);
-    rip_multipass=false;
+    cmd=QString().
+      sprintf("rd_rip_cd %d %s %d 0 %d %d %d %d %s %s/%s %s/%s %d",
+	      rip_track_number,
+	      (const char *)rdlibrary_conf->ripperDevice(),
+	      rdlibrary_conf->paranoiaLevel(),
+	      rdlibrary_conf->defaultFormat(),
+	      rip_channels_box->currentItem()+1,
+	      rdlibrary_conf->defaultSampleRate(),
+	      (rip_channels_box->currentItem()+1)*
+	      rdlibrary_conf->defaultBitrate()/1000,
+	      (const char *)rip_wavefile,
+	      RIPPER_TEMP_DIR,
+	      RIPPER_TEMP_PEAK,
+	      RIPPER_TEMP_DIR,
+	      RIPPER_TEMP_WAV,
+	      rdlibrary_conf->srcConverter());
   }
   ripper_running=true;
   bar_temp_file=new QFile(QString(RIPPER_TEMP_DIR)+QString("/")+
@@ -887,29 +884,25 @@ void DiskRipper::RipTrack(int track,QString cutname,QString title)
 
 int DiskRipper::GetTotalLength()
 {
-  unsigned length=0;
   unsigned raw_length=0;
   QListViewItem *item=rip_track_list->firstChild();
   while(item!=NULL) {
     if(!item->text(5).isEmpty()) {
-      length+=(unsigned)((double)rip_cdrom->
+      raw_length+=(unsigned)((double)rip_cdrom->
 			 trackLength(item->text(0).toInt())*176.4);
     }
     item=item->nextSibling();
   }
-  if(rip_normalize_box->isChecked()) {
-    raw_length=length;
-  }
   switch(rdlibrary_conf->defaultFormat()) {
       case 0:  // PCM16
-	return (int)(((double)length/2.0)*
+	return (int)(((double)raw_length/2.0)*
 		     (double)(rip_channels_box->currentItem()+1.0)*
 		     (double)rdlibrary_conf->defaultSampleRate()/44100.0)+
 	  raw_length;
 	break;
       case 1:  // MPEG-1 Layer 2
       case 2:  // MPEG-1 Layer 3
-	return (int)((double)length*
+	return (int)((double)raw_length*
 		     (double)(rip_channels_box->currentItem()+1)*
 		     (double)rdlibrary_conf->defaultBitrate()/1411200.0)+
 	  raw_length;
