@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: list_reports.cpp,v 1.4 2007/07/09 07:21:12 stgabriel Exp $
+//      $Id: list_reports.cpp,v 1.6.2.1 2009/03/30 12:04:41 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,10 +23,9 @@
 #include <qdialog.h>
 #include <qpushbutton.h>
 #include <qlabel.h>
-#include <qsqldatabase.h>
-
-#include <rconf.h>
 
+#include <rddb.h>
+#include <rdconf.h>
 #include <rdtextfile.h>
 #include <rdcart_search_text.h>
 #include <rdcart.h>
@@ -147,7 +146,7 @@ void ListReports::closeData()
 void ListReports::GenerateCartReport(QString *report)
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
 
   //
   // Generate Header
@@ -185,7 +184,7 @@ void ListReports::GenerateCartReport(QString *report)
 	      (const char *)RDCartSearchText(list_filter,list_group).utf8(),
 	      (const char *)list_type_filter);
   }
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     //
     // Cart Type
@@ -197,6 +196,7 @@ void ListReports::GenerateCartReport(QString *report)
 
 	case RDCart::Macro:
 	  *report+="  M  ";
+	  break;
 
 	default:
 	  *report+="  ?  ";
@@ -218,7 +218,7 @@ void ListReports::GenerateCartReport(QString *report)
     //
     *report+=
       QString().sprintf("%5s ",
-	       (const char *)RGetTimeLength(q->value(3).toInt(),false,false));
+	       (const char *)RDGetTimeLength(q->value(3).toInt(),false,false));
 
     //
     // Title
@@ -269,7 +269,7 @@ void ListReports::GenerateCartReport(QString *report)
     //
     *report+=
       QString().sprintf("%7s ",
-	       (const char *)RGetTimeLength(q->value(9).toInt(),false,true));
+	       (const char *)RDGetTimeLength(q->value(9).toInt(),false,true));
 
     //
     // Owner
@@ -294,7 +294,7 @@ void ListReports::GenerateCartReport(QString *report)
 void ListReports::GenerateCutReport(QString *report)
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   unsigned current_cart=0;
 
   //
@@ -336,7 +336,7 @@ void ListReports::GenerateCutReport(QString *report)
 	      (const char *)RDCartSearchText(list_filter,list_group).utf8(),
 	      (const char *)list_type_filter);
   }
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     //
     // Cart Number
@@ -381,7 +381,7 @@ void ListReports::GenerateCutReport(QString *report)
     //
     *report+=
       QString().sprintf("%5s ",
-	       (const char *)RGetTimeLength(q->value(5).toInt(),false,false));
+	       (const char *)RDGetTimeLength(q->value(5).toInt(),false,false));
 
     //
     // Last Play
@@ -493,7 +493,7 @@ void ListReports::GenerateCutReport(QString *report)
 void ListReports::GenerateCartDump(QString *report)
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
 
   *report="CART  |";
   *report+="CUT|";
@@ -533,7 +533,7 @@ void ListReports::GenerateCartDump(QString *report)
 	      (const char *)RDCartSearchText(list_filter,list_group).utf8(),
 	      (const char *)list_type_filter);
   }
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     //
     // Cart Number
@@ -616,7 +616,7 @@ void ListReports::GenerateCartDump(QString *report)
     // Length
     //
     *report+=QString().sprintf("%9s|",
-	     (const char *)RGetTimeLength(q->value(13).toInt(),true,true));
+	     (const char *)RDGetTimeLength(q->value(13).toInt(),true,true));
 
     //
     // End of Line
