@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: record_cut.h,v 1.30 2007/09/14 14:06:56 fredg Exp $
+//      $Id: record_cut.h,v 1.30.2.1 2010/01/20 22:22:51 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -41,6 +41,7 @@
 #include <rdcae.h>
 #include <rdcart.h>
 #include <rdcut.h>
+#include <rdtimeedit.h>
 
 #include <globals.h>
 
@@ -104,9 +105,9 @@ class RecordCut : public QDialog
    QLabel *cut_daypart_label;
    QRadioButton *cut_starttime_enable_button;
    QRadioButton *cut_starttime_disable_button;
-   QTimeEdit *cut_starttime_edit;
+   RDTimeEdit *cut_starttime_edit;
    QLabel *cut_starttime_label;
-   QTimeEdit *cut_endtime_edit;
+   RDTimeEdit *cut_endtime_edit;
    QLabel *cut_endtime_label;
    QTimer *rec_timer;
    QLabel *rec_timer_label;
