@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_marker.cpp,v 1.18 2008/04/02 16:47:26 fredg Exp $
+//      $Id: edit_marker.cpp,v 1.18.2.1 2010/02/08 23:50:14 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -64,8 +64,10 @@ EditMarker::EditMarker(RDLogLine *line,QWidget *parent,const char *name)
   //
   // Start Time
   //
-  edit_time_edit=new QTimeEdit(this,"edit_time_edit");
-  edit_time_edit->setGeometry(90,19,80,20);
+  edit_time_edit=new RDTimeEdit(this,"edit_time_edit");
+  edit_time_edit->setGeometry(85,19,85,20);
+  edit_time_edit->setDisplay(RDTimeEdit::Hours|RDTimeEdit::Minutes|
+			     RDTimeEdit::Seconds|RDTimeEdit::Tenths);
   connect(edit_time_edit,SIGNAL(valueChanged(const QTime &)),
 	  this,SLOT(timeChangedData(const QTime &)));
 
@@ -212,7 +214,8 @@ void EditMarker::timeChangedData(const QTime &time)
     str=QString(tr("Transition If Previous Cart Ends Before"));
     edit_time_label->
       setText(QString().sprintf("%s %s:",(const char *)str,
-		  (const char *)edit_time_edit->time().toString("hh:mm:ss")));
+				(const char *)edit_time_edit->time().
+				toString("hh:mm:ss.zzz").left(10)));
   }
 }
 
@@ -228,7 +231,8 @@ void EditMarker::timeToggledData(bool state)
     str=QString(tr("Transition If Previous Cart Ends Before"));
     edit_time_label->
       setText(QString().sprintf("%s %s:",(const char *)str,
-		  (const char *)edit_time_edit->time().toString("hh:mm:ss")));
+		  (const char *)edit_time_edit->time().
+				toString("hh:mm:ss.zzz").left(10)));
   }
   else {
     edit_grace_box->setDisabled(true);
