@@ -488,6 +488,14 @@ Gruppe des ausgewählten Service!</translation>
         <source>No Fade on Segue Out</source>
         <translation>Kein Faden beim Segue Out</translation>
     </message>
+    <message>
+        <source>Duplicate Start Time</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>An event is already scheduled with this start time!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditMarker</name>
