@@ -3,478 +3,497 @@
     <name>AddMeta</name>
     <message>
         <source>Insert a:</source>
-        <translation type="unfinished"></translation>
+        <translation>Insertar:</translation>
     </message>
     <message>
         <source>&amp;Marker</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Marcador</translation>
     </message>
     <message>
         <source>Log C&amp;hain</source>
-        <translation type="unfinished"></translation>
+        <translation>Enca&amp;denar a playlist</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Cancelar</translation>
     </message>
     <message>
         <source>Voice &amp;Track</source>
-        <translation type="unfinished"></translation>
+        <translation>Pista de &amp;voz</translation>
     </message>
 </context>
 <context>
     <name>EditChain</name>
     <message>
         <source>Edit Log Chain</source>
-        <translation type="unfinished"></translation>
+        <translation>Editar encadenamiento</translation>
     </message>
     <message>
         <source>Start at:</source>
-        <translation type="unfinished"></translation>
+        <translation>Iniciar en:</translation>
     </message>
     <message>
         <source>Action If Previous Event Still Playing</source>
-        <translation type="unfinished"></translation>
+        <translation>Acción si el evento previo no ha terminado</translation>
     </message>
     <message>
         <source>Start Immediately</source>
-        <translation type="unfinished"></translation>
+        <translation>Iniciar de inmediato</translation>
     </message>
     <message>
         <source>Make Next</source>
-        <translation type="unfinished"></translation>
+        <translation>Convertir en el siguente</translation>
     </message>
     <message>
         <source>Wait up to</source>
-        <translation type="unfinished"></translation>
+        <translation>Esperar hasta</translation>
     </message>
     <message>
         <source>Play</source>
-        <translation type="unfinished"></translation>
+        <translation>Reproducir</translation>
     </message>
     <message>
         <source>Segue</source>
-        <translation type="unfinished"></translation>
+        <translation>Segue</translation>
     </message>
     <message>
         <source>Stop</source>
-        <translation type="unfinished"></translation>
+        <translation>Detener</translation>
     </message>
     <message>
         <source>Transition Type:</source>
-        <translation type="unfinished"></translation>
+        <translation>Tipo de transición:</translation>
     </message>
     <message>
         <source>Log Name</source>
-        <translation type="unfinished"></translation>
+        <translation>Nombre del playlist</translation>
     </message>
     <message>
         <source>Select</source>
-        <translation type="unfinished"></translation>
+        <translation>Seleccionar</translation>
     </message>
     <message>
         <source>Log Description</source>
-        <translation type="unfinished"></translation>
+        <translation>Descripción</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Aceptar</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Cancelar</translation>
     </message>
     <message>
         <source>Transition If Previous Cart Ends Before</source>
-        <translation type="unfinished"></translation>
+        <translation>Transición si el cartucho previo termina antes</translation>
     </message>
 </context>
 <context>
     <name>EditLog</name>
     <message>
         <source>Edit Log</source>
-        <translation type="unfinished"></translation>
+        <translation>Editar playlist</translation>
     </message>
     <message>
         <source>Log Name:</source>
-        <translation type="unfinished"></translation>
+        <translation>Nombre:</translation>
     </message>
     <message>
         <source>Origin:</source>
-        <translation type="unfinished"></translation>
+        <translation>Origen:</translation>
     </message>
     <message>
         <source>Description:</source>
-        <translation type="unfinished"></translation>
+        <translation>Descripción:</translation>
     </message>
     <message>
         <source>Service:</source>
-        <translation type="unfinished"></translation>
+        <translation>Servicio:</translation>
     </message>
     <message>
         <source>Start Date:</source>
-        <translation type="unfinished"></translation>
+        <translation>Fecha de inicio:</translation>
     </message>
     <message>
         <source>End Date:</source>
-        <translation type="unfinished"></translation>
+        <translation>Fecha fin:</translation>
     </message>
     <message>
         <source>Start Date Enabled</source>
-        <translation type="unfinished"></translation>
+        <translation>Fecha de inicio activada</translation>
     </message>
     <message>
         <source>End Date Enabled</source>
-        <translation type="unfinished"></translation>
+        <translation>Fecha de fin activada</translation>
     </message>
     <message>
         <source>TIME</source>
-        <translation type="unfinished"></translation>
+        <translation>TIEMPO</translation>
     </message>
     <message>
         <source>TRANS</source>
-        <translation type="unfinished"></translation>
+        <translation>TRANS</translation>
     </message>
     <message>
         <source>CART</source>
-        <translation type="unfinished"></translation>
+        <translation>CARTUCHO</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation type="unfinished"></translation>
+        <translation>GRUPO</translation>
     </message>
     <message>
         <source>LENGTH</source>
-        <translation type="unfinished"></translation>
+        <translation>DURACIÓN</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation type="unfinished"></translation>
+        <translation>TÍTULO</translation>
     </message>
     <message>
         <source>ARTIST</source>
-        <translation type="unfinished"></translation>
+        <translation>ARTISTA</translation>
     </message>
     <message>
         <source>CLIENT</source>
-        <translation type="unfinished"></translation>
+        <translation>CLIENTE</translation>
     </message>
     <message>
         <source>AGENCY</source>
-        <translation type="unfinished"></translation>
+        <translation>AGENCIA</translation>
     </message>
     <message>
         <source>LABEL</source>
-        <translation type="unfinished"></translation>
+        <translation>ETIQUETA</translation>
     </message>
     <message>
         <source>LINE ID</source>
-        <translation type="unfinished"></translation>
+        <translation>ID LÍNEA</translation>
     </message>
     <message>
         <source>COUNT</source>
-        <translation type="unfinished"></translation>
+        <translation>CUENTA</translation>
     </message>
     <message>
         <source>Insert
 Cart</source>
-        <translation type="unfinished"></translation>
+        <translation>Insertar
+Cartucho</translation>
     </message>
     <message>
         <source>Insert
 Meta</source>
-        <translation type="unfinished"></translation>
+        <translation>Insertar
+Meta</translation>
     </message>
     <message>
         <source>Edit</source>
-        <translation type="unfinished"></translation>
+        <translation>Editar</translation>
     </message>
     <message>
         <source>Delete</source>
-        <translation type="unfinished"></translation>
+        <translation>Eliminar</translation>
     </message>
     <message>
         <source>Cut</source>
-        <translation type="unfinished"></translation>
+        <translation>Cortar</translation>
     </message>
     <message>
         <source>Copy</source>
-        <translation type="unfinished"></translation>
+        <translation>Copiar</translation>
     </message>
     <message>
         <source>Paste</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <source>&amp;Save</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Guardar</translation>
     </message>
     <message>
         <source>Save
 &amp;As</source>
-        <translation type="unfinished"></translation>
+        <translation>Guardar
+&amp;como</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Aceptar</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Cancelar</translation>
     </message>
     <message>
         <source>Invalid Carts</source>
-        <translation type="unfinished"></translation>
+        <translation>Cartuchos inválidos</translation>
     </message>
     <message>
         <source>This log contains one or more carts
 that are invalid for the selected service!</source>
-        <translation type="unfinished"></translation>
+        <translation>¡Este playlist contiene uno o más cartuchos
+que son inválidos para el dispositivo elegido!</translation>
     </message>
     <message>
         <source>The log contains carts that are disabled
 for the selected service!</source>
-        <translation type="unfinished"></translation>
+        <translation>¡El playlist contiene cartuchos que están
+desactivados para el dispositivo seleccionado!</translation>
     </message>
     <message>
         <source>Add Log</source>
-        <translation type="unfinished"></translation>
+        <translation>Agregar playlist</translation>
     </message>
     <message>
         <source>Log Exists</source>
-        <translation type="unfinished"></translation>
+        <translation>El playlist existe</translation>
     </message>
     <message>
         <source>Log Already Exists!</source>
-        <translation type="unfinished"></translation>
+        <translation>¡El playlist ya existe!</translation>
     </message>
     <message>
         <source>RDLogEdit</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <source>The log has been modified.
 Do you want to save your changes?</source>
-        <translation type="unfinished"></translation>
+        <translation>El playlist ha sido modificado.
+¿Desea guardar los cambios?</translation>
     </message>
     <message>
         <source>PLAY</source>
-        <translation type="unfinished"></translation>
+        <translation>REPROD</translation>
     </message>
     <message>
         <source>STOP</source>
-        <translation type="unfinished"></translation>
+        <translation>DETENER</translation>
     </message>
     <message>
         <source>SEGUE</source>
-        <translation type="unfinished"></translation>
+        <translation>SEGUE</translation>
     </message>
     <message>
         <source>[cart not found]</source>
-        <translation type="unfinished"></translation>
+        <translation>[cartucho no encontrado]</translation>
     </message>
     <message>
         <source>MARKER</source>
-        <translation type="unfinished"></translation>
+        <translation>MARCADOR</translation>
     </message>
     <message>
         <source>LOG CHAIN</source>
-        <translation type="unfinished"></translation>
+        <translation>ENCADENAR A PLAYLIST</translation>
     </message>
     <message>
         <source>--- end of log ---</source>
-        <translation type="unfinished"></translation>
+        <translation>--- fin de playlist ---</translation>
     </message>
     <message>
         <source>SOURCE</source>
-        <translation type="unfinished"></translation>
+        <translation>FUENTE</translation>
     </message>
     <message>
         <source>Manual</source>
-        <translation type="unfinished"></translation>
+        <translation>Manual</translation>
     </message>
     <message>
         <source>Traffic</source>
-        <translation type="unfinished"></translation>
+        <translation>Tráfico</translation>
     </message>
     <message>
         <source>Music</source>
-        <translation type="unfinished"></translation>
+        <translation>Música</translation>
     </message>
     <message>
         <source>RDLogManager</source>
-        <translation type="unfinished"></translation>
+        <translation>RDLogManager</translation>
     </message>
     <message>
         <source>TRACK</source>
-        <translation type="unfinished"></translation>
+        <translation>PISTA</translation>
     </message>
     <message>
         <source>Voice Tracker</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <source>Tracks:</source>
-        <translation type="unfinished"></translation>
+        <translation>Pistas:</translation>
     </message>
     <message>
         <source>Voice Track</source>
-        <translation type="unfinished"></translation>
+        <translation>Pista de voz</translation>
     </message>
     <message>
         <source>LINK</source>
-        <translation type="unfinished"></translation>
+        <translation>ENLACE</translation>
     </message>
     <message>
         <source>[traffic import]</source>
-        <translation type="unfinished"></translation>
+        <translation>[importar tráfico]</translation>
     </message>
     <message>
         <source>[music import]</source>
-        <translation type="unfinished"></translation>
+        <translation>[importar música]</translation>
     </message>
     <message>
         <source>The log contains carts that are disabled
 for the selected service!
 
 Do you still want to save?</source>
-        <translation type="unfinished"></translation>
+        <translation>¡El playlist contiene cartuchos que están 
+desactivados para el servicio actual!
+
+¿Aún así desea guardarlo?</translation>
     </message>
     <message>
         <source>[INVALID CART]</source>
-        <translation type="unfinished"></translation>
+        <translation>[CARTUCHO INVÁLIDO]</translation>
     </message>
     <message>
         <source>Yes</source>
-        <translation type="unfinished"></translation>
+        <translation>Sí</translation>
     </message>
     <message>
         <source>No</source>
-        <translation type="unfinished"></translation>
+        <translation>No</translation>
     </message>
     <message>
         <source>Enable AutoRefresh:</source>
-        <translation type="unfinished"></translation>
+        <translation>Activar AutoActualizar:</translation>
     </message>
     <message>
         <source>&amp;Reports</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Reportes</translation>
     </message>
     <message>
         <source>Next Stop:</source>
-        <translation type="unfinished"></translation>
+        <translation>Próxima parada:</translation>
     </message>
     <message>
         <source>Log End:</source>
-        <translation type="unfinished"></translation>
+        <translation>Fin del playlist:</translation>
     </message>
     <message>
         <source>Run Length</source>
-        <translation type="unfinished"></translation>
+        <translation>Duración total</translation>
     </message>
     <message>
         <source>Selected:</source>
-        <translation type="unfinished"></translation>
+        <translation>Seleccionado:</translation>
     </message>
     <message>
         <source>Delete on</source>
-        <translation type="unfinished"></translation>
+        <translation>Borrar el</translation>
     </message>
     <message>
         <source>Select</source>
-        <translation type="unfinished"></translation>
+        <translation>Seleccionar</translation>
     </message>
 </context>
 <context>
     <name>EditLogLine</name>
     <message>
         <source>Edit Log Entry</source>
-        <translation type="unfinished"></translation>
+        <translation>Editar entrada</translation>
     </message>
     <message>
         <source>Start at:</source>
-        <translation type="unfinished"></translation>
+        <translation>Iniciar en:</translation>
     </message>
     <message>
         <source>Action If Previous Event Still Playing</source>
-        <translation type="unfinished"></translation>
+        <translation>Acción si el evento previo no ha terminado</translation>
     </message>
     <message>
         <source>Start Immediately</source>
-        <translation type="unfinished"></translation>
+        <translation>Iniciar de inmediato</translation>
     </message>
     <message>
         <source>Make Next</source>
-        <translation type="unfinished"></translation>
+        <translation>Convertir en el siguente</translation>
     </message>
     <message>
         <source>Wait up to</source>
-        <translation type="unfinished"></translation>
+        <translation>Esperar hasta</translation>
     </message>
     <message>
         <source>Play</source>
-        <translation type="unfinished"></translation>
+        <translation>Reproducir</translation>
     </message>
     <message>
         <source>Segue</source>
-        <translation type="unfinished"></translation>
+        <translation>Segue</translation>
     </message>
     <message>
         <source>Stop</source>
-        <translation type="unfinished"></translation>
+        <translation>Detener</translation>
     </message>
     <message>
         <source>Transition Type:</source>
-        <translation type="unfinished"></translation>
+        <translation>Tipo de transición:</translation>
     </message>
     <message>
         <source>Cart</source>
-        <translation type="unfinished"></translation>
+        <translation>Cartucho</translation>
     </message>
     <message>
         <source>Title</source>
-        <translation type="unfinished"></translation>
+        <translation>Título</translation>
     </message>
     <message>
         <source>Artist</source>
-        <translation type="unfinished"></translation>
+        <translation>Artista</translation>
     </message>
     <message>
         <source>Select
 Cart</source>
-        <translation type="unfinished"></translation>
+        <translation>Seleccionar
+cartucho</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Aceptar</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Cancelar</translation>
     </message>
     <message>
         <source>Transition If Previous Cart Ends Before</source>
-        <translation type="unfinished"></translation>
+        <translation>Transición si el cartucho previo termina antes</translation>
     </message>
     <message>
         <source>Missing Cart</source>
-        <translation type="unfinished"></translation>
+        <translation>Cartucho no encontrado</translation>
     </message>
     <message>
         <source>You must supply a cart number!</source>
-        <translation type="unfinished"></translation>
+        <translation>¡Debe introducir un número de cartucho!</translation>
     </message>
     <message>
         <source>Disabled Cart</source>
-        <translation type="unfinished"></translation>
+        <translation>Cartucho desactivado</translation>
     </message>
     <message>
         <source>This cart belongs to a disabled
 group for the specified service!</source>
-        <translation type="unfinished"></translation>
+        <translation>¡Este cartucho pertenece a un grupo que está 
+desactivado para el servicio especificado!</translation>
     </message>
     <message>
         <source>No Fade on Segue Out</source>
+        <translation>Sin &quot;fade&quot; en un segue de salida</translation>
+    </message>
+    <message>
+        <source>Duplicate Start Time</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>An event is already scheduled with this start time!</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -482,318 +501,329 @@ group for the specified service!</source>
     <name>EditMarker</name>
     <message>
         <source>Edit Log Marker</source>
-        <translation type="unfinished"></translation>
+        <translation>Editar marcador</translation>
     </message>
     <message>
         <source>Start at:</source>
-        <translation type="unfinished"></translation>
+        <translation>Iniciar en:</translation>
     </message>
     <message>
         <source>Action If Previous Event Still Playing</source>
-        <translation type="unfinished"></translation>
+        <translation>Acción si el evento previo no ha terminado</translation>
     </message>
     <message>
         <source>Start Immediately</source>
-        <translation type="unfinished"></translation>
+        <translation>Iniciar de inmediato</translation>
     </message>
     <message>
         <source>Make Next</source>
-        <translation type="unfinished"></translation>
+        <translation>Convertir en el siguente</translation>
     </message>
     <message>
         <source>Wait up to</source>
-        <translation type="unfinished"></translation>
+        <translation>Esperar hasta</translation>
     </message>
     <message>
         <source>Play</source>
-        <translation type="unfinished"></translation>
+        <translation>Reproducir</translation>
     </message>
     <message>
         <source>Segue</source>
-        <translation type="unfinished"></translation>
+        <translation>Segue</translation>
     </message>
     <message>
         <source>Stop</source>
-        <translation type="unfinished"></translation>
+        <translation>Detener</translation>
     </message>
     <message>
         <source>Comment</source>
-        <translation type="unfinished"></translation>
+        <translation>Comentario</translation>
     </message>
     <message>
         <source>Label</source>
-        <translation type="unfinished"></translation>
+        <translation>Etiqueta</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Aceptar</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Cancelar</translation>
     </message>
     <message>
         <source>Transition If Previous Cart Ends Before</source>
-        <translation type="unfinished"></translation>
+        <translation>Transición si el cartucho previo termina antes</translation>
     </message>
     <message>
         <source>Transition Type:</source>
-        <translation type="unfinished"></translation>
+        <translation>Tipo de transición:</translation>
     </message>
 </context>
 <context>
     <name>EditTrack</name>
     <message>
         <source>Edit Voice Track Marker</source>
-        <translation type="unfinished"></translation>
+        <translation>Editar marcador de Voicetrack</translation>
     </message>
     <message>
         <source>Start at:</source>
-        <translation type="unfinished"></translation>
+        <translation>Iniciar en:</translation>
     </message>
     <message>
         <source>Action If Previous Event Still Playing</source>
-        <translation type="unfinished"></translation>
+        <translation>Acción si el evento previo no ha terminado</translation>
     </message>
     <message>
         <source>Start Immediately</source>
-        <translation type="unfinished"></translation>
+        <translation>Iniciar de inmediato</translation>
     </message>
     <message>
         <source>Make Next</source>
-        <translation type="unfinished"></translation>
+        <translation>Convertir en el siguente</translation>
     </message>
     <message>
         <source>Wait up to</source>
-        <translation type="unfinished"></translation>
+        <translation>Esperar hasta</translation>
     </message>
     <message>
         <source>Play</source>
-        <translation type="unfinished"></translation>
+        <translation>Reproducir</translation>
     </message>
     <message>
         <source>Segue</source>
-        <translation type="unfinished"></translation>
+        <translation>Segue</translation>
     </message>
     <message>
         <source>Stop</source>
-        <translation type="unfinished"></translation>
+        <translation>Detener</translation>
     </message>
     <message>
         <source>Comment</source>
-        <translation type="unfinished"></translation>
+        <translation>Comentario</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Aceptar</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Cancelar</translation>
     </message>
     <message>
         <source>Transition If Previous Cart Ends Before</source>
-        <translation type="unfinished"></translation>
+        <translation>Transición si el cartucho previo termina antes</translation>
     </message>
     <message>
         <source>Transition Type:</source>
-        <translation type="unfinished"></translation>
+        <translation>Tipo de transición:</translation>
     </message>
 </context>
 <context>
     <name>ListLogs</name>
     <message>
         <source>Select a Log</source>
-        <translation type="unfinished"></translation>
+        <translation>Seleccione un playlist</translation>
     </message>
     <message>
         <source>NAME</source>
-        <translation type="unfinished"></translation>
+        <translation>NOMBRE</translation>
     </message>
     <message>
         <source>DESCRIPTION</source>
-        <translation type="unfinished"></translation>
+        <translation>DESCRIPCIÓN</translation>
     </message>
     <message>
         <source>SERVICE</source>
-        <translation type="unfinished"></translation>
+        <translation>SERVICIO</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Aceptar</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Cancelar</translation>
     </message>
 </context>
 <context>
     <name>ListReports</name>
     <message>
         <source>RDLibrary Reports</source>
-        <translation type="unfinished"></translation>
+        <translation>Reportes de RDLibrary</translation>
     </message>
     <message>
         <source>Log Listing</source>
-        <translation type="unfinished"></translation>
+        <translation>Lista de Playlists</translation>
     </message>
     <message>
         <source>Log Exception Report</source>
-        <translation type="unfinished"></translation>
+        <translation>Reporte de Excepciones</translation>
     </message>
     <message>
         <source>Type:</source>
-        <translation type="unfinished"></translation>
+        <translation>Tipo:</translation>
     </message>
     <message>
         <source>&amp;Generate</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Generar</translation>
     </message>
     <message>
         <source>&amp;Close</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Cerrar</translation>
     </message>
     <message>
         <source>Log Check</source>
-        <translation type="unfinished"></translation>
+        <translation>Chequear playlist</translation>
     </message>
     <message>
         <source>No exceptions found.</source>
-        <translation type="unfinished"></translation>
+        <translation>No se encontraron excepciones.</translation>
     </message>
     <message>
         <source>[none]</source>
-        <translation type="unfinished"></translation>
+        <translation>[ninguno]</translation>
+    </message>
+    <message>
+        <source>Effective Date:</source>
+        <translation>Fecha efectiva:</translation>
+    </message>
+    <message>
+        <source>&amp;Select</source>
+        <translation>&amp;Seleccionar</translation>
     </message>
 </context>
 <context>
     <name>MainWidget</name>
     <message>
         <source>RDLogEdit - Host</source>
-        <translation type="unfinished"></translation>
+        <translation>RDLogEdit - Computador </translation>
     </message>
     <message>
         <source>User: [Unknown]</source>
-        <translation type="unfinished"></translation>
+        <translation>Usuario: [Desconocido]</translation>
     </message>
     <message>
         <source>Can&apos;t Connect</source>
-        <translation type="unfinished"></translation>
+        <translation>No puedo conectarme</translation>
     </message>
     <message>
         <source>LOG NAME</source>
-        <translation type="unfinished"></translation>
+        <translation>NOMBRE DEL PLAYLIST</translation>
     </message>
     <message>
         <source>DESCRIPTION</source>
-        <translation type="unfinished"></translation>
+        <translation>DESCRIPCIÓN</translation>
     </message>
     <message>
         <source>SERVICE</source>
-        <translation type="unfinished"></translation>
+        <translation>SERVICIO</translation>
     </message>
     <message>
         <source>VALID FROM</source>
-        <translation type="unfinished"></translation>
+        <translation>VÁLIDO DESDE</translation>
     </message>
     <message>
         <source>VALID TO</source>
-        <translation type="unfinished"></translation>
+        <translation>VÁLIDO HASTA</translation>
     </message>
     <message>
         <source>ORIGIN</source>
-        <translation type="unfinished"></translation>
+        <translation>ORIGEN</translation>
     </message>
     <message>
         <source>&amp;Add</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Añadir</translation>
     </message>
     <message>
         <source>&amp;Edit</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Editar</translation>
     </message>
     <message>
         <source>&amp;Delete</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Borrar</translation>
     </message>
     <message>
         <source>&amp;Close</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Cerrar</translation>
     </message>
     <message>
         <source>User</source>
-        <translation type="unfinished"></translation>
+        <translation>Usuario</translation>
     </message>
     <message>
         <source>Add Log</source>
-        <translation type="unfinished"></translation>
+        <translation>Agregar playlist</translation>
     </message>
     <message>
         <source>Log Exists</source>
-        <translation type="unfinished"></translation>
+        <translation>El playlist existe</translation>
     </message>
     <message>
         <source>Log Already Exists!</source>
-        <translation type="unfinished"></translation>
+        <translation>¡El playlist ya existe!</translation>
     </message>
     <message>
         <source>Always</source>
-        <translation type="unfinished"></translation>
+        <translation>Siempre</translation>
     </message>
     <message>
         <source>TFN</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <source>This will also delete the</source>
-        <translation type="unfinished"></translation>
+        <translation>Esto también borrará los </translation>
     </message>
     <message>
         <source>voice tracks associated with this log.
 Continue?</source>
-        <translation type="unfinished"></translation>
+        <translation> voicetracks asociados a esta lista.
+¿Desea continuar?</translation>
     </message>
     <message>
         <source>Tracks Exist</source>
-        <translation type="unfinished"></translation>
+        <translation>La pista ya existe</translation>
     </message>
     <message>
         <source>TRACKS</source>
-        <translation type="unfinished"></translation>
+        <translation>PISTAS</translation>
     </message>
     <message>
         <source>Voice
 &amp;Tracker</source>
-        <translation type="unfinished"></translation>
+        <translation>Voice
+&amp;Tracker</translation>
     </message>
     <message>
         <source>Delete Log</source>
-        <translation type="unfinished"></translation>
+        <translation>Eliminar playlist</translation>
     </message>
     <message>
         <source>MUSIC</source>
-        <translation type="unfinished"></translation>
+        <translation>MÚSICA</translation>
     </message>
     <message>
         <source>TRAFFIC</source>
-        <translation type="unfinished"></translation>
+        <translation>TRÁFICO</translation>
     </message>
     <message>
         <source>LAST LINKED</source>
-        <translation type="unfinished"></translation>
+        <translation>ÚLTIMO ENLACE</translation>
     </message>
     <message>
         <source>LAST MODIFIED</source>
-        <translation type="unfinished"></translation>
+        <translation>ÚLTIMO CAMBIO</translation>
     </message>
     <message>
         <source>AUTO REFRESH</source>
-        <translation type="unfinished"></translation>
+        <translation>AUTO ACTUALIZAR</translation>
     </message>
     <message>
         <source>Log
 Report</source>
-        <translation type="unfinished"></translation>
+        <translation>Reporte
+de PlayList</translation>
     </message>
 </context>
 </TS>
