@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdlogin.h,v 1.11.2.1 2008/12/09 15:45:24 fredg Exp $
+//      $Id: rdlogin.h,v 1.11.2.2 2010/01/31 22:24:55 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -24,7 +24,7 @@
 #ifndef RDLOGIN_H
 #define RDLOGIN_H
 
-#include <qdialog.h>
+#include <qwidget.h>
 #include <qsize.h>
 #include <qsizepolicy.h>
 #include <qsqldatabase.h>
@@ -38,7 +38,7 @@
 #include <rdconfig.h>
 
 
-class MainWidget : public QDialog
+class MainWidget : public QWidget
 {
   Q_OBJECT
  public:
