@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: local_macros.cpp,v 1.49.2.11 2009/09/18 21:26:14 cvs Exp $
+//      $Id: local_macros.cpp,v 1.49.2.11.2.2 2010/05/08 23:01:57 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -452,6 +452,40 @@ void MainObject::LoadLocalMacros()
 		  this,SLOT(gpoChangedData(int,int,bool)));
 	  break;
 
+	case RDMatrix::BtSrc8III:
+	  ripcd_btsrc8iii[q->value(0).toInt()]=new BtSrc8Iii(matrix,this);
+	  ripcd_switcher_tty[matrix->matrix()][0]=
+	    matrix->port(RDMatrix::Primary);
+	  ripcd_switcher_tty[matrix->matrix()][1]=-1;
+	  ripcd_tty_inuse[matrix->port(RDMatrix::Primary)]=true;
+	  connect(ripcd_btsrc8iii[q->value(0).toInt()],
+		  SIGNAL(rmlEcho(RDMacro *)),
+		  this,SLOT(sendRml(RDMacro *)));
+	  connect(ripcd_btsrc8iii[q->value(0).toInt()],
+		  SIGNAL(gpiChanged(int,int,bool)),
+		  this,SLOT(gpiChangedData(int,int,bool)));
+	  connect(ripcd_btsrc8iii[q->value(0).toInt()],
+		  SIGNAL(gpoChanged(int,int,bool)),
+		  this,SLOT(gpoChangedData(int,int,bool)));
+	  break;
+
+	case RDMatrix::BtSrc16:
+	  ripcd_btsrc16[q->value(0).toInt()]=new BtSrc16(matrix,this);
+	  ripcd_switcher_tty[matrix->matrix()][0]=
+	    matrix->port(RDMatrix::Primary);
+	  ripcd_switcher_tty[matrix->matrix()][1]=-1;
+	  ripcd_tty_inuse[matrix->port(RDMatrix::Primary)]=true;
+	  connect(ripcd_btsrc16[q->value(0).toInt()],
+		  SIGNAL(rmlEcho(RDMacro *)),
+		  this,SLOT(sendRml(RDMacro *)));
+	  connect(ripcd_btsrc16[q->value(0).toInt()],
+		  SIGNAL(gpiChanged(int,int,bool)),
+		  this,SLOT(gpiChangedData(int,int,bool)));
+	  connect(ripcd_btsrc16[q->value(0).toInt()],
+		  SIGNAL(gpoChanged(int,int,bool)),
+		  this,SLOT(gpoChangedData(int,int,bool)));
+	  break;
+
 	default:
 	  break;
     }
@@ -1085,6 +1119,14 @@ void MainObject::RunLocalMacros(RDMacro *rml)
 	  ripcd_btss44[rml->arg(0).toInt()]->processCommand(rml);
 	  break;
 	  
+	case RDMatrix::BtSrc8III:
+	  ripcd_btsrc8iii[rml->arg(0).toInt()]->processCommand(rml);
+	  break;
+	  
+	case RDMatrix::BtSrc16:
+	  ripcd_btsrc16[rml->arg(0).toInt()]->processCommand(rml);
+	  break;
+	  
 	default:
 	  if(rml->echoRequested()) {
 	    rml->acknowledge(false);
@@ -1293,6 +1335,18 @@ void MainObject::RunLocalMacros(RDMacro *rml)
 	  ripcd_matrix_type[matrix_num]=RDMatrix::None;
 	  break;
 	  
+	case RDMatrix::BtSrc8III:
+	  delete ripcd_btsrc8iii[matrix_num];
+	  ripcd_btsrc8iii[matrix_num]=NULL;
+	  ripcd_matrix_type[matrix_num]=RDMatrix::None;
+	  break;
+	  
+	case RDMatrix::BtSrc16:
+	  delete ripcd_btsrc16[matrix_num];
+	  ripcd_btsrc16[matrix_num]=NULL;
+	  ripcd_matrix_type[matrix_num]=RDMatrix::None;
+	  break;
+	  
 	default:
 	  break;
       }
@@ -1610,6 +1664,40 @@ void MainObject::RunLocalMacros(RDMacro *rml)
 		  this,SLOT(gpoChangedData(int,int,bool)));
 	  break;
 	  
+	case RDMatrix::BtSrc8III:
+	  ripcd_btsrc8iii[matrix_num]=new BtSrc8Iii(matrix);
+	  ripcd_matrix_type[matrix_num]=RDMatrix::BtSrc8III;
+	  ripcd_switcher_tty[matrix_num][0]=
+	    matrix->port(RDMatrix::Primary);
+	  ripcd_switcher_tty[matrix_num][1]=-1;
+	  ripcd_tty_inuse[matrix->port(RDMatrix::Primary)]=true;
+	  connect(ripcd_btsrc8iii[matrix_num],SIGNAL(rmlEcho(RDMacro *)),
+		  this,SLOT(sendRml(RDMacro *)));
+	  connect(ripcd_btsrc8iii[matrix_num],
+		  SIGNAL(gpiChanged(int,int,bool)),
+		  this,SLOT(gpiChangedData(int,int,bool)));
+	  connect(ripcd_btsrc8iii[matrix_num],
+		  SIGNAL(gpoChanged(int,int,bool)),
+		  this,SLOT(gpoChangedData(int,int,bool)));
+	  break;
+	  
+	case RDMatrix::BtSrc16:
+	  ripcd_btsrc16[matrix_num]=new BtSrc16(matrix);
+	  ripcd_matrix_type[matrix_num]=RDMatrix::BtSrc16;
+	  ripcd_switcher_tty[matrix_num][0]=
+	    matrix->port(RDMatrix::Primary);
+	  ripcd_switcher_tty[matrix_num][1]=-1;
+	  ripcd_tty_inuse[matrix->port(RDMatrix::Primary)]=true;
+	  connect(ripcd_btsrc16[matrix_num],SIGNAL(rmlEcho(RDMacro *)),
+		  this,SLOT(sendRml(RDMacro *)));
+	  connect(ripcd_btsrc16[matrix_num],
+		  SIGNAL(gpiChanged(int,int,bool)),
+		  this,SLOT(gpiChangedData(int,int,bool)));
+	  connect(ripcd_btsrc16[matrix_num],
+		  SIGNAL(gpoChanged(int,int,bool)),
+		  this,SLOT(gpoChangedData(int,int,bool)));
+	  break;
+	  
 	default:
 	  break;
       }
